/*
 * Newt-Puzzle
 * Copyright (C) Aude Jaulent 2008, 2009 <elderme@tuxfamily.org>
 * 
 * Newt-Puzzle is free software: you can redistribute it and/or modify it
 * under the terms of the GNU General Public License as published by the
 * Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * Newt-Puzzle is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
 * See the GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License along
 * with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

#ifndef _SCOREFOUR_H_
#define _SCOREFOUR_H_

#include <vector>

#include "../game.h"
#include "gridCubeSF.h"
#include "../ticTacToe/ticTacToeKeyboardOptions.h"
#include "../ticTacToe/ticTacToeOptions.h"

#include "../score.h"


#define LIMIT_CAM_SF_UP 0.95
#define LIMIT_CAM_SF_DOWN 0.35

 
class ScoreFour: public Game
{
public:
	ScoreFour();
	~ScoreFour();

	void initDisplayEnvironments ();				
	void createLights ();		
	void createScore();
	void createMenu();

		
	void updateAnimations(double currentTime, double intervalTime);	
		
	void initGame();
	virtual void reinitPosCamera() = 0;	
					
	void quit();			
	
	virtual int hitToPosition(int hit, int player) = 0;
	virtual void insertEntity(int position, int player) = 0;
		
	//keyboard
	bool keyboardEvent(SDLKey key, double timeInterval);
		
	//mouse events
	void mouseMotion(int xOld, int yOld, int xNew, int yNew, bool left, bool middle, bool right);
	void leftClick(int x, int y);
	void rightClick(int x, int y);
	void middleClick(int x, int y);	
	void mouseWheel(int w);			
		
			
protected:
	int gameDisplayIndex, scoreDisplayIndex, menuIndex;	
	
	Camera *gameCamera;
	Fog *gameFog;
	float distInitCam;
	float distCam;

	Grid *grid;	
		
	LightSpot *spot;
	std::vector<LightPoint*> ligthsPoint;	
		
		
	Camera *scoreCamera;
	LightSpot *spotScore;
	Fog *scoreFog;
		
	Score *score;	

	Camera *menuCamera;
	LightSpot *spotMenu;
	NewtMenu *menu;		
		
	TicTacToeOptions *options;
		
		
	int player;
	int remainingMoves;

};

class ScoreFourCube: public ScoreFour
{
public:	
	ScoreFourCube();	
		
	void reinitPosCamera();
	void createObjects ();
	
	int hitToPosition(int hit, int player);
	void insertEntity(int position, int player);
			
			
private:

		
};

#endif // _SCOREFOUR_H_
